
% converts coefficients of direct form to cascaded biquad form
% there must be an IIR filter object called filt1 exported from sptool
% the result is stored in the following order: 
% cascaded = [ -c1_a1; -c1_a2; c1_b1; c1_b2; ...
%              -c2_a1; -c2_a2; c2_b1; c2_b2; ...
%              ...
%              gain ]

format long

b = filt1.tf.num';
a = filt1.tf.den';

z = roots( b); % zeros
p = roots( a); % poles


% assume an even order! 
% --> complex conjugated pairs only

cascaded = [];

for i = 1:2:length(b)-1

  cascaded( (i-1)*2 + 1) =  2 * real( p(i));    % -a1
  cascaded( (i-1)*2 + 2) = -( abs( p(i)) )^2;   % -a2
  cascaded( (i-1)*2 + 3) = -2 * real( z(i));    % b1
  cascaded( (i-1)*2 + 4) =  ( abs( z(i)) )^2;   % b2

end

cascaded( end+1) =  b(1);   % gain

cascaded = cascaded'; % column vector



% effect of coefficient quantization
Q15 = 2^15;

  % direct form
a_quant = fix( a*Q15) / Q15;
b_quant = fix( b*Q15) / Q15;

  % stability?
p_abs = abs( roots( a_quant));

  % cascade form
cascaded_quant = fix( cascaded*Q15) / Q15;

  % stability?
