
/* iir_cas_float.h
 * Christian Feldbauer    Oct. 4, 2001
 * feldbauer@inw.tugraz.at
 */   


typedef struct
{
  unsigned num_cas; /* number of cascaded biquads */
  unsigned blksz;   /* number of signal samples per block */
  float *coeffs;    /* pointer to the coefficients array */
  float gain;       /* gain factor: product of all b0 */
  float *states;    /* pointer to the array for delay states */
  
} struct_iir_cas_float;

/* use iir_cas_float_init() to define this struct !!! */

/* cascaded biquad coefficients:
   { -c1_a1, -c1_a2, c1_b1', c1_b2', 
     -c2_a1, -c2_a2, c2_b1', c2_b2', 
     ..., 
     gain
   };
   note: there are only 4 coefficients per stage <==> ci_bj' = ci_bj/ci_b0
   note: gain = c1_b0 * c2_b0 * ...
   note: the matlab compatible difference equation is used:
         y(n) = b1' * x(n-1) + b2' * x(n-2) - a1 * y(n-1) - a2 * y(n-2)
   
   note: the number of cascaded biquads must be greater than or equal to 2
*/

/* I M P O R T A N T ! ! !
   
   The coefficients array MUST be aligned on a double word (64-bit)	boundary!
   
   e.g.:
   #pragma DATA_ALIGN( array_name, 8);
*/


void iir_cas_float_init( struct_iir_cas_float *data, float *coeffs, unsigned num_cas, unsigned blksz);

void iir_cas_float( struct_iir_cas_float *data, float *sigbuf); 
