
/* iir_dir_float.h
 * Christian Feldbauer    Oct. 24, 2001
 * feldbauer@inw.tugraz.at
 */   


typedef struct
{
  unsigned order;   /* number of delay elements */
  unsigned blksz;   /* number of signal samples per block */
  float *a;         /* pointer to the (normalized) denominator coefficients array
                       of size order */
  float *b;         /* pointer to the numerator coefficients array
                       of size order+1 */
  float *states;    /* pointer to the array for delay states */
  int cur;          /* used for circular buffer */
  
} struct_iir_dir_float;

/* use iir_dir_float_init() to define this struct !!! 
   (e.g. states must be aligned properly)
*/

/* direct form coefficients:
   a = { a1, a2, ..., aN};
   b = { b0, b1, b2, ..., bN };
   where N is the order

   note: the matlab compatible difference equation is used:
         y(n) = b0*x(n) + b1*x(n-1) + b2*x(n-2) + ...
                        - a1*y(n-1) - a2*y(n-2) - ...
*/


void iir_dir_float_init( struct_iir_dir_float *data, float *b, float *a, unsigned order, unsigned blksz);

void iir_dir_float( struct_iir_dir_float *data, float *sigbuf); 

